olive/client_registry
The client_registry module holds a list of connected clients (browsers)
and allows to trigger those clients by sending them a Reload message.
Types
pub type ClientMessage {
Reload
}
Constructors
-
Reload
pub opaque type ClientRegistry