olive/watcher
The watcher module watches a list of dir and triggers a FilesChanged message
to be handled by calling code.
Types
pub opaque type InternalMsg
The watcher module watches a list of dir and triggers a FilesChanged message
to be handled by calling code.
pub opaque type InternalMsg